@@ -4,6 +4,7 @@ use Moose;
 use Carp;
 use namespace::autoclean;
 use Expect;
+use open qw(:std :utf8);
 
 # 使用 'PDK::Device::Base' 角色
 with 'PDK::Device::Base';
@@ -215,7 +216,7 @@ sub runningConfig {
 #------------------------------------------------------------------------------
 # 具体实现 healthCheckCommands,设置抓取设备健康检查配置的脚本
 #------------------------------------------------------------------------------
-sub healthCheckConfig {
+sub healthCheck {
   my $self     = shift;
   my $commands = [
     "show system resources",
