@@ -4,6 +4,7 @@ use Moose;
 use Carp;
 use namespace::autoclean;
 use Expect;
+use open qw(:std :utf8);
 
 # 使用 'PDK::Device::Base' 角色
 with 'PDK::Device::Base';
@@ -124,7 +125,7 @@ sub getConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 startupCommands,设置抓取设备启动配置的脚本
+# 具体实现 startupConfig,设置抓取设备启动配置的脚本
 #------------------------------------------------------------------------------
 sub startupConfig {
   my $self     = shift;
@@ -134,7 +135,7 @@ sub startupConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 runningCommands,设置抓取设备运行配置的脚本
+# 具体实现 runningConfig,设置抓取设备运行配置的脚本
 #------------------------------------------------------------------------------
 sub runningConfig {
   my $self     = shift;
@@ -144,9 +145,9 @@ sub runningConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 healthCheckCommands,设置抓取设备健康检查配置的脚本
+# 具体实现 healthCheck,设置抓取设备健康检查配置的脚本
 #------------------------------------------------------------------------------
-sub healthCheckConfig {
+sub healthCheck {
   my $self     = shift;
   my $commands = ["set cli pager off", "set cli config-output-format set", "configure", "show", "exit"];
 
