@@ -4,6 +4,7 @@ use Moose;
 use Carp;
 use namespace::autoclean;
 use Expect;
+use open qw(:std :utf8);
 
 # 使用 'PDK::Device::Base' 角色
 with 'PDK::Device::Base';
@@ -161,7 +162,7 @@ sub getConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 startupCommands,设置抓取设备启动配置的脚本
+# 具体实现 startupConfig,设置抓取设备启动配置的脚本
 #------------------------------------------------------------------------------
 sub startupConfig {
   my $self     = shift;
@@ -171,7 +172,7 @@ sub startupConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 runningCommands,设置抓取设备运行配置的脚本
+# 具体实现 runningConfig,设置抓取设备运行配置的脚本
 #------------------------------------------------------------------------------
 sub runningConfig {
   my $self     = shift;
@@ -181,9 +182,9 @@ sub runningConfig {
 }
 
 #------------------------------------------------------------------------------
-# 具体实现 healthCheckCommands,设置抓取设备健康检查配置的脚本
+# 具体实现 healthCheck,设置抓取设备健康检查配置的脚本
 #------------------------------------------------------------------------------
-sub healthCheckConfig {
+sub healthCheck {
   my $self     = shift;
   my $commands = ["cfg/dump", "cd"];
 
